==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkSimpleScalarTree.java <==
// java wrapper for vtkSimpleScalarTree object
//

package vtk;
import vtk.*;

public class vtkSimpleScalarTree extends vtkScalarTree
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBranchingFactor_2(int id0);
  public void SetBranchingFactor(int id0)
    { SetBranchingFactor_2(id0); }

  private native int GetBranchingFactorMinValue_3();
  public int GetBranchingFactorMinValue()
    { return GetBranchingFactorMinValue_3(); }

  private native int GetBranchingFactorMaxValue_4();
  public int GetBranchingFactorMaxValue()
    { return GetBranchingFactorMaxValue_4(); }

  private native int GetBranchingFactor_5();
  public int GetBranchingFactor()
    { return GetBranchingFactor_5(); }

  private native int GetLevel_6();
  public int GetLevel()
    { return GetLevel_6(); }

  private native void SetMaxLevel_7(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_7(id0); }

  private native int GetMaxLevelMinValue_8();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_8(); }

  private native int GetMaxLevelMaxValue_9();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_9(); }

  private native int GetMaxLevel_10();
  public int GetMaxLevel()
    { return GetMaxLevel_10(); }

  private native void BuildTree_11();
  public void BuildTree()
    { BuildTree_11(); }

  private native void Initialize_12();
  public void Initialize()
    { Initialize_12(); }

  private native void InitTraversal_13(double id0);
  public void InitTraversal(double id0)
    { InitTraversal_13(id0); }

  public vtkSimpleScalarTree() { super(); }

  public vtkSimpleScalarTree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSimpleScalarTree.java <==
// java wrapper for vtkSimpleScalarTree object
//

package vtk;
import vtk.*;

public class vtkSimpleScalarTree extends vtkScalarTree
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBranchingFactor_2(int id0);
  public void SetBranchingFactor(int id0)
    { SetBranchingFactor_2(id0); }

  private native int GetBranchingFactorMinValue_3();
  public int GetBranchingFactorMinValue()
    { return GetBranchingFactorMinValue_3(); }

  private native int GetBranchingFactorMaxValue_4();
  public int GetBranchingFactorMaxValue()
    { return GetBranchingFactorMaxValue_4(); }

  private native int GetBranchingFactor_5();
  public int GetBranchingFactor()
    { return GetBranchingFactor_5(); }

  private native int GetLevel_6();
  public int GetLevel()
    { return GetLevel_6(); }

  private native void SetMaxLevel_7(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_7(id0); }

  private native int GetMaxLevelMinValue_8();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_8(); }

  private native int GetMaxLevelMaxValue_9();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_9(); }

  private native int GetMaxLevel_10();
  public int GetMaxLevel()
    { return GetMaxLevel_10(); }

  private native void BuildTree_11();
  public void BuildTree()
    { BuildTree_11(); }

  private native void Initialize_12();
  public void Initialize()
    { Initialize_12(); }

  private native void InitTraversal_13(double id0);
  public void InitTraversal(double id0)
    { InitTraversal_13(id0); }

  private native int GetNumberOfCellBatches_14();
  public int GetNumberOfCellBatches()
    { return GetNumberOfCellBatches_14(); }

  public vtkSimpleScalarTree() { super(); }

  public vtkSimpleScalarTree(long id) { super(id); }
  public native long   VTKInit();

}
